---
name: Bug report
about: Report an issue in the 'illumio' library
---

<!-- Problem overview -->

## Expected Result

<!-- What you expected to happen -->

## Actual Result

<!-- What actually happened -->

## Steps to reproduce

```python
import illumio

```

## System Information

<!-- Information about your system - python version, OS, packages installed, 
    anything you think could help identify or may contribute to the problem -->

**Are you able to help contribute a fix for this issue?** yes/no
